Configuration
=============

## Available settings:

BOOKING_TITLE:
  > Title of create booking page

BOOKING_DESC
  > Description of create booking page

-----

## Usage:
add this var to settings.py

```python
BOOKING_TITLE = "Your title"
BOOKING_DESC = "Your description"
```
